==> m2tools-0.1.4.tar.gz: m2tools-0.1.4/m2tools/extension.py <==
import zipfile
import os, shutil
import re
import json
import zipfile

from tempfile import mkdtemp

from .patcher import Patcher, PhpCode, JsCode, XmlCode


class VerfiedDescriptior:
    def __init__(self):
        self.val = {}

    def __get__(self, obj, objtype):
        return self.val[obj]

    def __set__(self, obj, val):
        self.val[obj] = val


class NameDescriptor(VerfiedDescriptior):

    def __set__(self, obj, val):
        if not re.match( "^([a-z0-9_-])+\/([a-z0-9_-])+$", val):
            raise ValueError("Name must be in <vendor>/<package name> format, \"%s\" given" % val)
        self.val[obj] = val


class VersionDescriptor(VerfiedDescriptior):

    def __set__(self, obj, val):
        # Check `version` field
        if not re.match("^(|v)([0-9])+\.([0-9])+\.([0-9])+(-(patch|p|dev|a|alpha|b|beta|rc)([0-9])*)?$", val):
            raise ValueError("Version must follow https://getcomposer.org/doc/04-schema.md#version"
                             "format, \"%s\" given" % val)
        self.val[obj] = val


class TypeDescriptor(VerfiedDescriptior):

    allowed = ("magento2-theme", "magento2-language", "magento2-module")

    def __set__(self, obj, val):
        if val not in self.allowed:
            raise ValueError("Type can only be one of the following:"
                             "magento2-theme, magento2-language, or magento2-module; %s given." % val)
        self.val[obj] = val


class Metadata:
    """
    Composer.json wrapper with m2-extension specific options and checks
    """

    name = NameDescriptor()
    version = VersionDescriptor()
    type = TypeDescriptor()

    def __init__(self):
        pass

    def init_from_file(self, fp):
        try:
            # Python 3.6+
            js = json.load(fp)
        except TypeError:
            # Python 3.5-
            js = json.loads(fp.read().decode('utf-8'))

        self.update(js)

    def update(self, values):
        for k, v in values.items():
            setattr(self, k, v)

    def __iter__(self):
        return iter({k: getattr(self, k) for k in dir(self) if not k.startswith('__') and not callable(getattr(self, k))}.items())


class Extension:

    def __init__(self, path=None):
        self.meta = Metadata()
        self.path = path
        if self.path:
            self.init_from_path(path)

    def init_from_path(self, path):
        self.path = path
        if not os.path.exists(os.path.join(self.path, 'registration.php')):
            raise IOError("registration.php file doesn't exist")

        with open(os.path.join(self.path, 'composer.json')) as jsfp:
            self.meta.init_from_file(jsfp)

    def init_from_zip(self, path):
        z = zipfile.ZipFile(path)
        for fn in z.namelist():
            if os.path.basename(fn) == 'composer.json':
                with z.open(fn) as fp:
                    self.meta.init_from_file(fp)
                    return
        raise IOError("No composer.json file found in {}". format(path))

==> m2tools-0.1.6.tar.gz: m2tools-0.1.6/m2tools/extension.py <==
import zipfile
import os, shutil
import re
import json
import zipfile

from tempfile import mkdtemp

from .patcher import Patcher, PhpCode, JsCode, XmlCode
import sys


class VerfiedDescriptior:
    def __init__(self):
        self.val = {}

    def __get__(self, obj, objtype):
        return self.val[obj]

    def __set__(self, obj, val):
        self.val[obj] = val


class NameDescriptor(VerfiedDescriptior):

    def __set__(self, obj, val):
        if not re.match( "^([a-z0-9_-])+\/([a-z0-9_-])+$", val):
            raise ValueError("Name must be in <vendor>/<package name> format, \"%s\" given" % val)
        self.val[obj] = val


class VersionDescriptor(VerfiedDescriptior):

    def __set__(self, obj, val):
        # Check `version` field
        if not re.match("^(|v)([0-9])+\.([0-9])+\.([0-9])+(-(patch|p|dev|a|alpha|b|beta|rc)([0-9])*)?$", val):
            raise ValueError("Version must follow https://getcomposer.org/doc/04-schema.md#version"
                             "format, \"%s\" given" % val)
        self.val[obj] = val


class TypeDescriptor(VerfiedDescriptior):

    allowed = ("magento2-theme", "magento2-language", "magento2-module")

    def __set__(self, obj, val):
        if val not in self.allowed:
            raise ValueError("Type can only be one of the following:"
                             "magento2-theme, magento2-language, or magento2-module; %s given." % val)
        self.val[obj] = val


class Metadata:
    """
    Composer.json wrapper with m2-extension specific options and checks
    """

    name = NameDescriptor()
    version = VersionDescriptor()
    type = TypeDescriptor()

    def __init__(self):
        pass

    def init_from_file(self, fp):

        if sys.version_info >= (3, 6):
            # Python 3.6+
            js = json.load(fp)
        else:
            # Python 3.5-
            try:
                js = json.load(fp)
            except TypeError:
                js = json.loads(fp.read().decode())

        self.update(js)

    def update(self, values):
        for k, v in values.items():
            setattr(self, k, v)

    def __iter__(self):
        return iter({k: getattr(self, k) for k in dir(self) if not k.startswith('__') and not callable(getattr(self, k))}.items())


class Extension:

    def __init__(self, path=None):
        self.meta = Metadata()
        self.path = path
        if self.path:
            self.init_from_path(path)

    def init_from_path(self, path):
        self.path = path
        if not os.path.exists(os.path.join(self.path, 'registration.php')):
            raise IOError("registration.php file doesn't exist")

        with open(os.path.join(self.path, 'composer.json')) as jsfp:
            self.meta.init_from_file(jsfp)

    def init_from_zip(self, path):
        z = zipfile.ZipFile(path)
        for fn in z.namelist():
            if os.path.basename(fn) == 'composer.json':
                with z.open(fn) as fp:
                    self.meta.init_from_file(fp)
                    return
        raise IOError("No composer.json file found in {}". format(path))
